# Upkie wheeled biped robot

URDF description for the [Upkie](https://www.youtube.com/watch?v=NO_TkHGS0wQ) wheeled biped. See also:

- [3D printing files](https://www.prusaprinters.org/prints/127831-upkie-wheeled-biped-robot/files)
- [Build instructions](https://www.prusaprinters.org/prints/127831-upkie-wheeled-biped-robot)

## License

The GPL 3.0 license applies to all files in this repository, to the exception of the [mjbots](meshes/mjbots) (Apache 2.0) and [wheel\_tire](meshes/wheel_tire) (CC-BY 4.0) meshes. See the license files in their respective folders for details.
